<p align="center">
    <img src="assets/images/header.png" alt="coimbra">
</p>

<h1 id="coimbra" align="center">
    coimbra
</h1>

<p align="center">
  <!-- TODO: https://bestpractices.coreinfrastructure.org/en -->
  <!-- TODO: https://www.gitpod.io/docs/getting-started -->
  <a href="https://pypi.org/project/coimbra/"><img src="https://img.shields.io/pypi/v/coimbra" alt="PyPI - Latest Release"></a>
  <a href="https://github.com/tpvasconcelos/coimbra/"><img src="https://img.shields.io/pypi/pyversions/coimbra" alt="PyPI - Python Versions"></a>
  <a href="https://pypi.org/project/coimbra/"><img src="https://img.shields.io/pypi/status/coimbra.svg" alt="PyPI - Package Status"></a>
  <a href="https://github.com/tpvasconcelos/coimbra/blob/master/LICENSE"><img src="https://img.shields.io/pypi/l/coimbra" alt="PyPI - License"></a>
  <a href="https://github.com/psf/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black"></a>
  <br>
  <a href="https://github.com/tpvasconcelos/coimbra/actions/workflows/test.yaml/"><img src="https://github.com/tpvasconcelos/coimbra/actions/workflows/test.yaml/badge.svg" alt="CI"></a>
  <a href="https://codecov.io/gh/tpvasconcelos/coimbra"><img src="https://codecov.io/gh/tpvasconcelos/coimbra/branch/master/graph/badge.svg" alt="codecov"></a>
  <a href="https://www.codefactor.io/repository/github/tpvasconcelos/coimbra"><img src="https://www.codefactor.io/repository/github/tpvasconcelos/coimbra/badge" alt="CodeFactor"></a>
  <a href="https://www.codacy.com/gh/tpvasconcelos/coimbra/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=tpvasconcelos/coimbra&amp;utm_campaign=Badge_Grade"><img src="https://app.codacy.com/project/badge/Grade/24e94a244a504de8a345b70f41c34445" alt="Codacy code quality"></a>
</p>

<p align="center"><i>Resources store</i></p>

---


# How to get it?

The source code is currently hosted on GitHub at: <https://github.com/tpvasconcelos/coimbra>

Install and update using [pip](https://pip.pypa.io/en/stable/quickstart/):

```bash
pip install coimbra
```
